@@ -3,7 +3,6 @@
 package src
 
 import (
-	"bufio"
 	"errors"
 	"fmt"
 	"os"
@@ -16,13 +15,14 @@ const tagPam = ""
 
 // PamHandle defines structure of handle specifically designed for using PAM authorization
 type pamHandle struct {
+	*authBase
 	trans *pam.Transaction
 	u     *sysuser
 }
 
 // Creates authHandle and handles authorization
 func auth(conf *config) *pamHandle {
-	h := &pamHandle{}
+	h := &pamHandle{authBase: &authBase{}}
 	h.authUser(conf)
 	return h
 }
@@ -32,33 +32,24 @@ func auth(conf *config) *pamHandle {
 //
 // If autologin is enabled, it behaves as user has been authorized.
 func (h *pamHandle) authUser(conf *config) {
-	h.trans, _ = pam.StartFunc("emptty", conf.DefaultUser, func(s pam.Style, msg string) (string, error) {
+	username, err := h.selectUser(conf)
+	handleErr(err)
+	if h.command != "" {
+		return
+	}
+
+	h.trans, _ = pam.StartFunc("emptty", username, func(s pam.Style, msg string) (string, error) {
 		switch s {
 		case pam.PromptEchoOff:
 			if conf.Autologin {
 				break
 			}
-			if conf.DefaultUser != "" && !conf.HideEnterLogin {
-				hostname, _ := os.Hostname()
-				fmt.Printf("%s login: %s\n", hostname, conf.DefaultUser)
-			}
 			if !conf.HideEnterPassword {
 				fmt.Print("Password: ")
 			}
 			return readPassword()
 		case pam.PromptEchoOn:
-			if conf.Autologin {
-				break
-			}
-			if !conf.HideEnterLogin {
-				hostname, _ := os.Hostname()
-				fmt.Printf("%s login: ", hostname)
-			}
-			input, err := bufio.NewReader(os.Stdin).ReadString('\n')
-			if err != nil {
-				return "", err
-			}
-			return input[:len(input)-1], nil
+			return "", nil
 		case pam.ErrorMsg:
 			logPrint(msg)
 			return "", nil
@@ -85,6 +76,7 @@ func (h *pamHandle) authUser(conf *config) {
 	usr, _ := user.Lookup(pamUsr)
 
 	h.u = getSysuser(usr)
+	h.saveLastSelectedUser(conf, pamUsr)
 }
 
 func (h *pamHandle) handleErr(err error) {
