@@ -20,6 +20,8 @@ const (
 	desktopLang        = "LANG"
 	desktopLoginShell  = "LOGINSHELL"
 	desktopNames       = "DESKTOPNAMES"
+	desktopNoDisplay   = "NODISPLAY"
+	desktopHidden      = "HIDDEN"
 
 	constEnvXorg    = "xorg"
 	constEnvWayland = "wayland"
@@ -40,6 +42,9 @@ const (
 	pathLastSession       = "/.cache/emptty/last-session"
 	pathCustomSessions    = "/etc/emptty/custom-sessions/"
 	pathUserCustomSession = "/.config/emptty-custom-sessions/"
+
+	pathLocalWaylandSessions = "/.local/share/wayland-sessions/"
+	pathLocalXSessions       = "/.local/share/xsessions/"
 )
 
 // enEnvironment defines possible Environments.
@@ -88,6 +93,8 @@ type desktop struct {
 	child        *desktop
 	loginShell   string
 	desktopNames string
+	noDisplay    bool
+	hidden       bool
 }
 
 // Gets exec path from desktop and returns true, if command allows dbus-launch.
@@ -100,6 +107,33 @@ func (d *desktop) getStrExec() (string, bool) {
 	return d.path, false
 }
 
+// Gets correct desktop name, if is available.
+func (d *desktop) getDesktopName() string {
+	if d.desktopNames != "" {
+		names := strings.Split(d.desktopNames, ":")
+		if len(names) > 0 {
+			return names[0]
+		}
+	}
+	return d.name
+}
+
+// Sets desktop names in expected format
+func (d *desktop) setDesktopNames(desktopNames string) {
+	val := sanitizeValue(desktopNames, "")
+	if val != "" {
+		var names []string
+		for _, name := range strings.Split(strings.ReplaceAll(val, ";", ":"), ":") {
+			if name != "" {
+				names = append(names, name)
+			}
+		}
+		if len(names) > 0 {
+			d.desktopNames = strings.Join(names, ":")
+		}
+	}
+}
+
 // lastSession defines structure for last used session on user login.
 type lastSession struct {
 	exec string
@@ -129,8 +163,8 @@ func selectDesktop(usr *sysuser, conf *config, d *desktop) (*desktop, *desktop)
 		}
 	}
 
-	// If there is just one desktop and selection is set to Auto, select first desktop
-	if len(desktops) == 1 && d != nil && d.selection == SelectionAuto {
+	// If there is just one desktop and AutoSelection is set or selection is set to Auto, select first desktop
+	if len(desktops) == 1 && (conf.AutoSelection || (d != nil && d.selection == SelectionAuto)) {
 		return desktops[0], desktops[lastDesktop]
 	}
 
@@ -217,39 +251,43 @@ func listAllDesktops(usr *sysuser, pathXorgDesktops, pathWaylandDesktops string)
 	var result []*desktop
 
 	// load Xorg desktops
-	result = append(result, listDesktops(pathXorgDesktops, Xorg)...)
+	result = append(result, listDesktops(Xorg, pathXorgDesktops, usr.homedir+pathLocalXSessions)...)
 
 	// load Wayland desktops
-	result = append(result, listDesktops(pathWaylandDesktops, Wayland)...)
+	result = append(result, listDesktops(Wayland, pathWaylandDesktops, usr.homedir+pathLocalWaylandSessions)...)
 
 	// load custom desktops
-	result = append(result, listDesktops(pathCustomSessions, Custom)...)
+	result = append(result, listDesktops(Custom, pathCustomSessions)...)
 
 	// load custom user desktops
-	result = append(result, listDesktops(usr.homedir+pathUserCustomSession, UserCustom)...)
+	result = append(result, listDesktops(UserCustom, usr.homedir+pathUserCustomSession)...)
 
 	return result
 }
 
-// List desktops, that could be found on defined path.
-func listDesktops(path string, env enEnvironment) []*desktop {
+// List desktops, that could be found on defined paths.
+func listDesktops(env enEnvironment, paths ...string) []*desktop {
 	var result []*desktop
 
-	if strings.HasSuffix(path, "/") {
-		path += "/"
-	}
+	for _, path := range paths {
+		if strings.HasSuffix(path, "/") {
+			path += "/"
+		}
 
-	if fileExists(path) {
-		err := filepath.Walk(path, func(filePath string, fileInfo os.FileInfo, err error) error {
-			if !fileInfo.IsDir() && strings.HasSuffix(filePath, ".desktop") {
-				d := getDesktop(filePath, env)
-				result = append(result, d)
-			}
-			return nil
-		})
-		handleErr(err)
-	}
+		if fileExists(path) {
+			err := filepath.Walk(path, func(filePath string, fileInfo os.FileInfo, err error) error {
+				if !fileInfo.IsDir() && strings.HasSuffix(filePath, ".desktop") {
+					d := getDesktop(filePath, env)
+					if !d.noDisplay && !d.hidden {
+						result = append(result, d)
+					}
+				}
+				return nil
+			})
+			handleErr(err)
+		}
 
+	}
 	return result
 }
 
@@ -269,7 +307,11 @@ func getDesktop(path string, env enEnvironment) *desktop {
 		case desktopEnvironment, desktopEnv:
 			d.env = parseEnv(value, constEnvXorg)
 		case desktopNames:
-			d.desktopNames = value
+			d.setDesktopNames(value)
+		case desktopNoDisplay:
+			d.noDisplay = parseBool(value, "false")
+		case desktopHidden:
+			d.hidden = parseBool(value, "false")
 		}
 	})
 	return &d
@@ -301,7 +343,7 @@ func loadUserDesktop(homeDir string) (d *desktop, lang string) {
 			case desktopLoginShell:
 				d.loginShell = sanitizeValue(value, "")
 			case desktopNames:
-				d.desktopNames = sanitizeValue(value, "")
+				d.setDesktopNames(value)
 			}
 		}, true)
 		handleErr(err)
