@@ -210,18 +210,18 @@ func TestGetLastDesktop(t *testing.T) {
 }
 
 func TestListDesktops(t *testing.T) {
-	desktops := listDesktops(getTestingPath("userHome"), Custom)
+	desktops := listDesktops(Custom, getTestingPath("userHome"))
 	if len(desktops) > 0 {
 		t.Error("TestListDesktops: no desktop was expected")
 	}
 
-	desktops = listDesktops(getTestingPath("desktops"), Custom)
+	desktops = listDesktops(Custom, getTestingPath("desktops"))
 	if len(desktops) == 0 {
 		t.Error("TestListDesktops: desktops were expected")
 	}
 
 	for _, d := range desktops {
-		if d.name == "Desktop1" && d.exec != "/usr/bin/desktop1" && d.desktopNames != "Desk1;DESKTOP_1" {
+		if d.name == "Desktop1" && (d.exec != "/usr/bin/desktop1" || d.desktopNames != "Desk1:DESKTOP_1") {
 			t.Error("TestListDesktops: wrongly loaded desktop")
 		}
 		if d.name == "Desktop2" && d.env != Wayland {
@@ -361,3 +361,17 @@ func TestGetDesktopBaseExec(t *testing.T) {
 		t.Error("TestGetDesktopBaseExec: wrong value for exec5")
 	}
 }
+
+func TestGetDesktopName(t *testing.T) {
+	d := getDesktop(getTestingPath("desktops/desktop1.desktop"), Custom)
+
+	if desktopName := d.getDesktopName(); desktopName != "Desk1" {
+		t.Errorf("TestGetDesktopName: desktop1 got unexpected desktop name '%s'", d.getDesktopName())
+	}
+
+	d = getDesktop(getTestingPath("desktops/desktop2.desktop"), Custom)
+
+	if desktopName := d.getDesktopName(); desktopName != "Desktop2" {
+		t.Errorf("TestGetDesktopName: desktop2 got unexpected desktop name '%s'", d.getDesktopName())
+	}
+}
