@@ -9,7 +9,7 @@ import (
 	"syscall"
 )
 
-const version = "0.12.1"
+const version = "0.13.0"
 
 var buildVersion string
 
@@ -36,7 +36,9 @@ func Main() {
 	initLogger(conf)
 	printMotd(conf)
 
-	login(conf, initSessionHandle())
+	if command := login(conf, initSessionHandle()); command != "" {
+		processCommand(command, conf)
+	}
 
 	stopDaemon(conf, fTTY)
 }
@@ -148,16 +150,17 @@ func nextArg(args []string, i int, callback func(value string)) {
 
 // Prints help
 func printHelp() {
-	fmt.Println("Usage: emptty [options]")
-	fmt.Println("Options:")
-	fmt.Printf("  -h, --help\t\t\tprint this help\n")
-	fmt.Printf("  -v, --version\t\t\tprint version\n")
-	fmt.Printf("  -d, --daemon\t\t\tstart in daemon mode\n")
-	fmt.Printf("  -c, --config PATH\t\tload configuration from specified path\n")
-	fmt.Printf("  -i, --ignore-config\t\tskips loading of configuration from file, loads only argument configuration\n")
-	fmt.Printf("  -t, --tty NUMBER\t\toverrides configured TTY number\n")
-	fmt.Printf("  -u, --default-user USER_NAME\toverrides configured Default User\n")
-	fmt.Printf("  -a, --autologin [SESSION]\toverrides configured autologin to true and if next argument is defined, it defines also Autologin Session.\n")
+	fmt.Print(`Usage: emptty [options]
+Options:
+  -h, --help			print this help
+  -v, --version			print version
+  -d, --daemon			start in daemon mode
+  -c, --config PATH		load configuration from specified path
+  -i, --ignore-config		skips loading of configuration from file, loads only argument configuration
+  -t, --tty NUMBER		overrides configured TTY number
+  -u, --default-user USER_NAME	overrides configured Default User
+  -a, --autologin [SESSION]	overrides configured autologin to true and if next argument is defined, it defines also Autologin Session
+`)
 }
 
 // Gets current version
@@ -177,3 +180,55 @@ func getVersion() string {
 	}
 	return version
 }
+
+// Process commands input in login buffer
+func processCommand(command string, c *config) {
+	switch command {
+	case "help", "?":
+		fmt.Print(`
+Available commands:
+  :help, :?			print this help
+  :poweroff, :shutdown		process poweroff command
+  :reboot			process reboot command
+  :suspend, :zzz		process suspend command
+`)
+		waitForReturnToExit(0)
+	case "poweroff", "shutdown":
+		if err := processCommandAsCmd(c.CmdPoweroff); err != nil {
+			handleErr(err)
+		} else {
+			waitForReturnToExit(0)
+		}
+	case "reboot":
+		if err := processCommandAsCmd(c.CmdReboot); err != nil {
+			handleErr(err)
+		} else {
+			waitForReturnToExit(0)
+		}
+	case "suspend", "zzz":
+		var variants []string
+		if c.CmdSuspend != "" {
+			variants = append(variants, c.CmdSuspend)
+		}
+		variants = append(variants, "zzz")
+		variants = append(variants, "systemctl suspend")
+		variants = append(variants, "loginctl suspend")
+
+		var err error
+		for _, v := range variants {
+			if err = processCommandAsCmd(v); err != nil {
+				continue
+			} else {
+				break
+			}
+		}
+
+		if err != nil {
+			handleErr(err)
+		} else {
+			waitForReturnToExit(0)
+		}
+	default:
+		handleStrErr(fmt.Sprintf("Unknown command '%s'", command))
+	}
+}
