@@ -94,7 +94,11 @@ func (s *commonSession) start() {
 	}
 
 	if s.dbus != nil {
-		s.dbus.launch(s.auth.usr())
+		if s.auth.usr().getenv(dbusSessionBusAddress) == "" || s.conf.AlwaysDbusLaunch {
+			s.dbus.launch(s.auth.usr())
+		} else {
+			logPrint("DBUS_SESSION_BUS_ADDRESS is already set, skipping start of DBUS_LAUNCH")
+		}
 	}
 
 	logPrint("Starting " + strExec)
@@ -115,7 +119,7 @@ func (s *commonSession) start() {
 
 	err := session.Wait()
 
-	if s.dbus != nil {
+	if s.dbus != nil && s.dbus.pid > 0 {
 		s.dbus.interrupt()
 	}
 
@@ -159,10 +163,10 @@ func (s *commonSession) defineEnvironment() {
 	if !s.conf.NoXdgFallback {
 		if s.d.name != "" {
 			s.auth.usr().setenv(envDesktopSession, s.d.name)
-			s.auth.usr().setenv(envXdgSessDesktop, s.d.name)
+			s.auth.usr().setenv(envXdgSessDesktop, s.d.getDesktopName())
 		} else if s.d.child != nil && s.d.child.name != "" {
 			s.auth.usr().setenv(envDesktopSession, s.d.child.name)
-			s.auth.usr().setenv(envXdgSessDesktop, s.d.child.name)
+			s.auth.usr().setenv(envXdgSessDesktop, s.d.child.getDesktopName())
 		}
 
 		if s.d.desktopNames != "" {
@@ -205,7 +209,7 @@ func (s *commonSession) prepareGuiCommand() (cmd *exec.Cmd, strExec string) {
 	}
 
 	if startScript {
-		cmd = cmdAsUser(s.auth.usr(), s.getLoginShell(), strings.Split(strExec, " ")...)
+		cmd = cmdAsUser(s.auth.usr(), s.getLoginShell()+" "+strExec)
 	} else {
 		cmd = cmdAsUser(s.auth.usr(), strExec)
 	}
