@@ -3,6 +3,7 @@ package src
 import (
 	"bufio"
 	"errors"
+	"fmt"
 	"net"
 	"os"
 	"os/exec"
@@ -180,7 +181,7 @@ func convertColor(name string, isForeground bool) string {
 // Prepares *exec.Cmd to be started as sysuser.
 func cmdAsUser(usr *sysuser, name string, arg ...string) *exec.Cmd {
 	if strings.Contains(name, " ") {
-		nameArgs := strings.Split(name, " ")
+		nameArgs := parseExec(name)
 		name = nameArgs[0]
 		arg = append(nameArgs[1:], arg...)
 	}
@@ -191,6 +192,48 @@ func cmdAsUser(usr *sysuser, name string, arg ...string) *exec.Cmd {
 	return cmd
 }
 
+// Processes selected command as exec.Cmd
+func processCommandAsCmd(name string) error {
+	var arg []string
+	if strings.Contains(name, " ") {
+		nameArgs := parseExec(name)
+		name = nameArgs[0]
+		arg = append(nameArgs[1:], arg...)
+	}
+	name, _ = exec.LookPath(name)
+	cmd := exec.Command(name, arg...)
+	return cmd.Run()
+}
+
+// Splits execString by spaces respecting double quotes.
+func parseExec(execString string) (result []string) {
+	var sb strings.Builder
+	inQuotes := false
+	escapeNext := false
+
+	for _, r := range execString {
+		switch {
+		case escapeNext:
+			escapeNext = false
+		case r == '\\':
+			escapeNext = true
+		case r == '"':
+			inQuotes = !inQuotes
+		case r == ' ' && !inQuotes:
+			if sb.Len() > 0 {
+				result = append(result, sb.String())
+				sb.Reset()
+				continue
+			}
+		}
+		sb.WriteRune(r)
+	}
+	if sb.Len() > 0 {
+		result = append(result, sb.String())
+	}
+	return
+}
+
 // Applies current resource limits
 func applyRlimits() {
 	rlimits := []int{syscall.RLIMIT_AS, syscall.RLIMIT_CORE, syscall.RLIMIT_CPU, syscall.RLIMIT_DATA, syscall.RLIMIT_FSIZE, syscall.RLIMIT_NOFILE, syscall.RLIMIT_STACK}
@@ -446,3 +489,11 @@ func chvt(tty int) bool {
 	}
 	return true
 }
+
+func waitForReturnToExit(code int) {
+	fmt.Printf("\nPress Enter to continue...")
+	if !TEST_MODE {
+		bufio.NewReader(os.Stdin).ReadString('\n')
+		os.Exit(code)
+	}
+}
